# must-tui

A terminal user interface application for MUST. MUST is the 'Mission Utility and Support Tools' framework which is used by most current spacecraft flight control teams at ESOC, DLR, and CNES. This TUI is a user friendly interface for user who prefer using a terminal.

## Features

- Fast and responsive CLI
- Cross-platform support
- Intuitive navigation

## Installation

```bash
uv tool install must-tui
```

## Usage

```bash
must-tui
```

## Development

```bash
git clone https://github.com/KU-Leuven/must-tui
cd must-tui
uv venv
source .venv/bin/activate
uv sync
```

## License

MIT

## Contributing

Contributions are welcome! Please open an issue or submit a pull request.
